.. :changelog:

History
-------

1.0.2 (2022-11-29)
~~~~~~~~~~~~~~~~~~

- Adding documentation and updating MLFlow version.

1.0.1 (2022-11-02)
~~~~~~~~~~~~~~~~~~

- Adding MANIFEST.in file to fix the distribution file.

1.0.0 (2022-10-19)
~~~~~~~~~~~~~~~~~~

- First version of the library.
